@@ -1,12 +1,8 @@
 package MooseX::Declare::Syntax::Keyword::Role;
-BEGIN {
-  $MooseX::Declare::Syntax::Keyword::Role::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $MooseX::Declare::Syntax::Keyword::Role::VERSION = '0.37';
-}
 # ABSTRACT: Role declarations
 
+our $VERSION = '0.43';
+
 use Moose;
 use Moose::Util qw(does_role find_meta);
 use aliased 'Parse::Method::Signatures' => 'PMS';
@@ -15,17 +11,41 @@ use aliased 'Parse::Method::Signatures::Param::Placeholder';
 use aliased 'MooseX::Declare::Context::Parameterized', 'ParameterizedCtx';
 use aliased 'MooseX::Declare::Syntax::MethodDeclaration::Parameterized', 'ParameterizedMethod';
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
+#pod =head1 CONSUMES
+#pod
+#pod =for :list
+#pod * L<MooseX::Declare::Syntax::MooseSetup>
+#pod * L<MooseX::Declare::Syntax::RoleApplication>
+#pod
+#pod =cut
 
 with qw(
     MooseX::Declare::Syntax::MooseSetup
     MooseX::Declare::Syntax::RoleApplication
 );
 
+#pod =head1 MODIFIED METHODS
+#pod
+#pod =head2 imported_moose_symbols
+#pod
+#pod   List Object->imported_moose_symbols ()
+#pod
+#pod Extends the existing L<MooseX::Declare::Syntax::MooseSetup/imported_moose_symbols>
+#pod with C<requires>, C<extends>, C<has>, C<inner> and C<super>.
+#pod
+#pod =cut
 
 around imported_moose_symbols => sub { shift->(@_), qw( requires excludes extends has inner super ) };
 
+#pod =head2 import_symbols_from
+#pod
+#pod   Str Object->import_symbols_from ()
+#pod
+#pod Will return L<Moose::Role> instead of the default L<Moose>.
+#pod
+#pod =cut
 
 around import_symbols_from => sub {
     my ($next, $self, $ctx) = @_;
@@ -34,6 +54,13 @@ around import_symbols_from => sub {
         : 'Moose::Role';
 };
 
+#pod =head2 make_anon_metaclass
+#pod
+#pod   Object Object->make_anon_metaclass ()
+#pod
+#pod This will return an anonymous instance of L<Moose::Meta::Role>.
+#pod
+#pod =cut
 
 around make_anon_metaclass => sub { Moose::Meta::Role->create_anon_role };
 
@@ -51,6 +78,13 @@ around default_inner => sub {
     return $inner;
 };
 
+#pod =method generate_export
+#pod
+#pod   CodeRef Object->generate_export ()
+#pod
+#pod Returns a closure with a call to L</make_anon_metaclass>.
+#pod
+#pod =cut
 
 sub generate_export { my $self = shift; sub { $self->make_anon_metaclass } }
 
@@ -117,6 +151,15 @@ after handle_post_parsing => sub {
     });
 };
 
+#pod =head1 SEE ALSO
+#pod
+#pod =for :list
+#pod * L<MooseX::Declare>
+#pod * L<MooseX::Declare::Syntax::Keyword::Class>
+#pod * L<MooseX::Declare::Syntax::RoleApplication>
+#pod * L<MooseX::Declare::Syntax::MooseSetup>
+#pod
+#pod =cut
 
 1;
 
@@ -124,12 +167,16 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 MooseX::Declare::Syntax::Keyword::Role - Role declarations
 
+=head1 VERSION
+
+version 0.43
+
 =head1 METHODS
 
 =head2 generate_export
